from ..utils.core_utils import CoreUtil as CoreUtil
from .config import GeneratorConfig as GeneratorConfig
from .meta_model import ColumnMetaModel as ColumnMetaModel, GenerateMetaModel as GenerateMetaModel, InitFileSchemaModel as InitFileSchemaModel
from _typeshed import Incomplete

class TemplateBuilder:
    output: Incomplete
    def __init__(self, *, config: GeneratorConfig) -> None: ...
    @classmethod
    def format_column(cls, column: ColumnMetaModel) -> str: ...
    def generate_init_file(self, *, schema_names, template_name: str): ...
    def generate_init_file_for_schema_router(self, *, meta_model: InitFileSchemaModel, template_name: str): ...
    def generate_code(self, *, meta_model: GenerateMetaModel, template_name: str, child_path=...): ...
    def get_generate_meta_model(self, *, table_name, schema_name) -> GenerateMetaModel: ...
    def get_schema_init_file_meta_model(self, *, schema_name, imports, routers) -> InitFileSchemaModel: ...
    def get_table_names(self, *, schema_name): ...
    def get_schema_names(self): ...
