from ..entity_table.dept import Dept as Dept, DeptCreate as DeptCreate, DeptResponse as DeptResponse, DeptUpdate as DeptUpdate
from _typeshed import Incomplete
from shudaodao_core import AsyncSession as AsyncSession, QueryRequest as QueryRequest

Dept_Router: Incomplete

async def dept_create(*, db: AsyncSession = ..., create_model: DeptCreate): ...
async def dept_read(*, db: AsyncSession = ..., primary_id: int): ...
async def dept_update(*, db: AsyncSession = ..., primary_id: int, model_update: DeptUpdate): ...
async def dept_delete(*, db: AsyncSession = ..., primary_id: int): ...
async def dept_query(*, db: AsyncSession = ..., query: QueryRequest): ...
